@@ -149,11 +149,14 @@ sub invoke {
     my ($help, $ofh, $ret);
     my $pool = SVN::Pool->new_default;
     $ofh = select $output if $output;
+    print $ret if $ret && $ret !~ /^\d+$/;
     local $SVN::Error::handler = sub {
 	my $error = $_[0];
 	my $error_message = $error->expanded_message();
 	$error->clear();
-	$cmd->handle_error ($error) if defined $cmd;
+	if ($cmd->handle_error ($error)) {
+	    die \'error handled';
+        }
 	die $error_message."\n";
     };
 
@@ -196,7 +199,15 @@ sub invoke {
     $ofh = select STDERR unless $output;
     print $ret if $ret && $ret !~ /^\d+$/;
     # if an error handler terminates editor call, there will be stack trace
-    print $@ if $@ && $@ !~ m/\n.+\n.+\n/;
+    unless (ref($@)) {
+	if ($SVN::Core::VERSION gt '1.2.2') {
+	    print $@ if $@;
+	}
+	else {
+	    # if an error handler terminates editor call, there will be stack trace
+	    print $@ if $@ && $@ !~ m/\n.+\n.+\n/
+	}
+    }
     $ret = 1 if ($ret ? $ret !~ /^\d+$/ : $@);
     undef $cmd; undef $pool; # this needs to happen before finish select
     select $ofh if $ofh;
