@@ -8,6 +8,10 @@ use SVK::XD;
 use SVK::Util qw( slurp_fh is_symlink );
 use SVK::I18N;
 
+sub options {
+    ("q|quiet"    => 'quiet');
+}
+
 sub parse_arg {
     my $self = shift;
     my @arg = @_;
@@ -32,13 +36,7 @@ sub run {
 	      absent_verbose => 1,
 	      nodelay => 1,
 	      cb_conflict => \&SVK::Editor::Status::conflict,
-	      cb_unknown => sub {
-		  my ($path, $copath) = @_;
-		  return unless $target->contains_copath ($copath);
-		  print loc("%1 is not versioned; ignored.\n",
-			    $target->report_copath ($copath));
-		  return;
-	      },
+	      cb_unknown => \&SVK::Editor::Status::unknown,
 	      editor => SVK::Editor::Status->new
 	      ( notify => SVK::Notify->new
 		( cb_flush => sub {
@@ -52,7 +50,12 @@ sub run {
 			  return $self->do_unschedule ($target, $copath)
 			      if ($st eq 'C' || $status->[2]) && !$xdroot->check_path ($dpath);
                           return $self->do_revert($target, $copath, $dpath, $xdroot);
-                      }
+                      } elsif ($st eq '?') {
+			  return unless $target->contains_copath ($copath);
+			  print loc("%1 is not versioned; ignored.\n",
+			      $target->report_copath ($copath));
+			  return;
+		      }
 
                       if ($target->{targets}) {
                           # Check that we are not reverting parents
@@ -93,7 +96,8 @@ sub do_unschedule {
     my ($self, $target, $copath) = @_;
     $self->{xd}{checkout}->store ($copath, { $self->_schedule_empty,
 					     '.conflict' => undef });
-    print loc("Reverted %1\n", $target->report_copath ($copath));
+    print loc("Reverted %1\n", $target->report_copath ($copath))
+	unless $self->{quiet};
 
 }
 
@@ -112,6 +116,7 @@ SVK::Command::Revert - Revert changes made in checkout copies
 =head1 OPTIONS
 
  -R [--recursive]       : descend recursively
+ -q [--quiet]           : print as little as possible
 
 =head1 AUTHORS
 
